@@ -27,9 +27,11 @@ load_dotenv()
 
 # Initialize configuration system early to load YAML config and set environment variables
 # This ensures OPENAI_API_KEY and other config values are available before LLM initialization
+# Skip this during tests to avoid overriding test environment variables
 from sqlbot.core.config import SQLBotConfig
-_early_config = SQLBotConfig.from_env()
-_early_config.apply_to_env()  # Apply config to environment variables
+if not os.getenv('PYTEST_CURRENT_TEST'):  # Only load config when not in pytest
+    _early_config = SQLBotConfig.from_env()
+    _early_config.apply_to_env()  # Apply config to environment variables
 
 # Theme-aware messaging system that uses the global theme manager
 class MessageStyle:
@@ -1438,8 +1440,8 @@ def start_unified_repl(memory_manager, console):
                             # Empty first line, return empty string
                             return ""
                     else:
-                        # Continuation lines with a different prompt
-                        line = input("... ")
+                        # Continuation lines with same prompt character
+                        line = input(f"{MessageSymbols.INPUT_PROMPT} ")
 
                         # If line is empty, we're done
                         if not line:
